@@ -9,10 +9,10 @@ from functools import partial
 from importlib import import_module
 from importlib.util import find_spec
 from inspect import getmodule
-from itertools import chain, count, zip_longest
+from itertools import chain, count, filterfalse, islice, takewhile, zip_longest
 from keyword import iskeyword
-from operator import attrgetter, eq
-from os import environ, extsep, path
+from operator import attrgetter, eq, itemgetter
+from os import environ, extsep, listdir, path
 from pprint import PrettyPrinter
 from sys import version_info
 from textwrap import fill as _fill
@@ -20,7 +20,7 @@ from textwrap import indent
 from typing import Callable, Dict, FrozenSet, Optional, Tuple, Union
 
 pp: Callable[[object], None] = PrettyPrinter(indent=4, width=100).pprint
-tab: str = " " * 4
+tab: str = environ.get("DOCTRANS_TAB", " " * 4)
 simple_types: Dict[Optional[str], Union[int, float, complex, str, bool, None]] = {
     "int": 0,
     "float": 0.0,
@@ -40,6 +40,53 @@ def rpartial(func, *args):
     return lambda *a: func(*(a + args))
 
 
+def remove_whitespace_comments(source):
+    """
+    Remove all nonsignficant whitespace and comments from source
+
+    :param source: Python source string
+    :type source: ```str```
+
+    :return: `source` without signficant whitespace and comments
+    :rtype: ```str```
+    """
+    return "\n".join(
+        filter(
+            None,
+            filterfalse(str.isspace, map(parse_comment_from_line, source.splitlines())),
+        )
+    )
+
+
+def parse_comment_from_line(line):
+    """
+    Remove from comment onwards in line
+
+    :param line: Python source line
+    :type line: ```str```
+
+    :return: `line` without comments
+    :rtype: ```str```
+    """
+    double = 0
+    single = 0
+    for col, ch in enumerate(line):
+        if col > 3 and line[col - 1] == "\\" and ch in frozenset(('"', "'", "#")):
+            pass  # Ignore the char
+        elif ch == '"':
+            double += 1
+        elif ch == "'":
+            single += 1
+        elif ch == "#" and single & 1 == 0 and double & 1 == 0:
+            col_offset = (
+                col
+                if col == 0
+                else (col - count_iter_items(takewhile(str.isspace, line[:col][::-1])))
+            )
+            return "".join(islice(line, 0, col_offset))
+    return line
+
+
 def identity(*args, **kwargs):
     """
     Identity function
@@ -378,6 +425,46 @@ def quote(s, mark='"'):
     return "{mark}{s}{mark}".format(mark=mark, s=s)
 
 
+def all_dunder_for_module(name, exclude):
+    """
+    Generate `__all__` for a given module using single-level filename hierarchy exclusively
+
+    :param name: Module name
+    :type name: ```str```
+
+    :param exclude: Strings to exclude
+    :type exclude: ```Iterable[str]```
+
+    :return: list of strings matching the expected `__all__`
+    :rtype: ```List[str]```
+    """
+    return sorted(
+        chain.from_iterable(
+            (
+                exclude,
+                filterfalse(
+                    rpartial(str.endswith, "utils"),
+                    map(
+                        itemgetter(0),
+                        map(
+                            path.splitext,
+                            filterfalse(
+                                rpartial(str.startswith, "_"),
+                                listdir(
+                                    path.join(
+                                        path.dirname(__file__),
+                                        name,
+                                    )
+                                ),
+                            ),
+                        ),
+                    ),
+                ),
+            )
+        )
+    )
+
+
 def assert_equal(a, b, cmp=eq):
     """
     assert a and b are equal
@@ -466,6 +553,37 @@ lstrip_diff = partial(diff, op=str.lstrip)
 rstrip_diff = partial(diff, op=str.rstrip)
 
 
+def balanced_parentheses(s):
+    """
+    Checks if parentheses are balanced, ignoring whatever is inside quotes
+
+    :param s: Input string
+    :type s: ```str```
+
+    :return: Whether the parens are balanced
+    :rtype: ```bool```
+    """
+    open_parens, closed_parens = "([{", ")]}"
+    counter = {paren: 0 for paren in open_parens + closed_parens}
+    quote_mark = None
+    for idx, ch in enumerate(s):
+        if (
+            quote_mark is not None
+            and ch == quote_mark
+            and (idx == 0 or s[idx - 1] != "\\")
+        ):
+            quote_mark = None
+        elif quote_mark is None:
+            if ch in frozenset(("'", '"')):
+                quote_mark = ch
+            elif ch in counter:
+                counter[ch] += 1
+    return all(
+        counter[open_parens[i]] == counter[closed_parens[i]]
+        for i in range(len(open_parens))
+    )
+
+
 def blockwise(t, size=2, fillvalue=None):
     """
     Blockwise, like pairwise but with a `size` parameter
@@ -676,21 +794,91 @@ def get_module(name, package=None, extra_symbols=None):
             raise
 
 
-def has_nl(s, func):
+def count_chars_from(
+    s, sentinel_char_unseen, char, end, s_len=len, start_idx=0, char_f=None
+):
     """
-    Check if str endswith a newline (possibly separated by other whitespace)
+    Count number of chars in string from one or other end, until `ignore` is no longer True (or entire `s` is covered)
+
+    :param s: Input string
+    :type s: ```str``
+
+    :param sentinel_char_unseen: Function that takes one char and decided whether to ignore it or not
+    :type sentinel_char_unseen: ```Callable[[str], bool]```
+
+    :param char: Single character for counting occurrences of
+    :type char: ```str```
+
+    :param end: True to look from the end; False to look from start
+    :type end: ```bool```
+
+    :param s_len: String len function to use, override to work at a shorter substr, e.g., `lambda _: 5`
+    :type s_len: ```Callable[str, [int]]```
+
+    :param start_idx: Index to start looking at string from, override to work at a shorter substr, e.g., `3`
+    :type start_idx: ```int```
+
+    :param char_f: char function, if `True` adds 1 to count. Overrides `char` if provided.
+    :type char_f: ```Optional[Callable[str, [bool]]```
+
+    :return: Number of chars counted (until `ignore`)
+    :rtype: ```int```
+    """
+    char_count = 0
+
+    if char_f is None:
+        char_f = rpartial(eq, char)
+
+    for i in range(*((s_len(s) - 1, start_idx, -1) if end else (start_idx, s_len(s)))):
+        if char_f(s[i]):
+            char_count += 1
+        elif not sentinel_char_unseen(s[i]):
+            break
+    return char_count
+
+
+num_of_nls = partial(count_chars_from, sentinel_char_unseen=str.isspace, char="\n")
+
+
+def is_triple_quoted(s):
+    """
+    Whether the str is triple quoted
 
     :param s: Input string
     :type s: ```str```
 
-    :param func: `str.partition` or `str.rpartition` function (or something similar)
-    :type func: ```Callable[[str], Tuple[str,str,str]]```
-
-    :return: Whether s endswith a newline (possibly separated by other whitespace)
+    :return: Whether it has balanced triple quotes (either variety)
     :rtype: ```bool```
     """
-    start, maybe_nl, end = partial(func, "\n")(s)
-    return maybe_nl == "\n" and start.isspace()
+    return len(s) > 5 and (
+        s.startswith("'''")
+        and s.endswith("'''")
+        or s.startswith('"""')
+        and s.endswith('"""')
+    )
+
+
+def is_ir_empty(intermediate_repr):
+    """
+    Checks whether the IR is empty, i.e., might have name and params but will generate a docstr without types or argdoc
+
+    :param intermediate_repr: a dictionary of form
+        {  "name": Optional[str],
+           "type": Optional[str],
+           "doc": Optional[str],
+           "params": OrderedDict[str, {'typ': str, 'doc': Optional[str], 'default': Any}]
+           "returns": Optional[OrderedDict[Literal['return_type'],
+                                           {'typ': str, 'doc': Optional[str], 'default': Any}),)]] }
+    :type intermediate_repr: ```dict```
+
+    :return: Whether IR is empty
+    :rtype: ```bool```
+    """
+    return not intermediate_repr.get("doc") and not any(
+        param_d is not None and (param_d.get("typ") or param_d.get("doc"))
+        for key in ("params", "returns")
+        for param_d in (intermediate_repr.get(key) or {}).values()
+    )
 
 
 def paren_wrap_code(code):
@@ -823,7 +1011,6 @@ sanitise_emit_name = dict(
     **{"class": "class_", "argparse": "argparse_function"}
 ).__getitem__
 
-
 __all__ = [
     "BUILTIN_TYPES",
     "DUNDERS",
@@ -832,9 +1019,12 @@ __all__ = [
     "PY3_8",
     "PY_GTE_3_8",
     "PY_GTE_3_9",
+    "all_dunder_for_module",
     "assert_equal",
+    "balanced_parentheses",
     "blockwise",
     "code_quoted",
+    "count_chars_from",
     "count_iter_items",
     "deindent",
     "diff",
@@ -842,21 +1032,24 @@ __all__ = [
     "filename_from_mod_or_filename",
     "fill",
     "get_module",
-    "has_nl",
     "identity",
     "indent_all_but_first",
+    "is_ir_empty",
+    "is_triple_quoted",
     "location_within",
     "lstrip_namespace",
     "multiline",
     "no_magic_dir2attr",
     "none_types",
+    "num_of_nls",
     "omit_whitespace",
     "paren_wrap_code",
+    "parse_comment_from_line",
     "pluralise",
     "pp",
-    # "previous_line_range",
     "quote",
     "reindent",
+    "remove_whitespace_comments",
     "rpartial",
     "sanitise",
     "sanitise_emit_name",
@@ -868,4 +1061,5 @@ __all__ = [
     "tab",
     "unquote",
     "update_d",
+    # "previous_line_range",
 ]
